aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--src/types.ts8
1 files changed, 5 insertions, 3 deletions
diff --git a/src/types.ts b/src/types.ts
index 10faa5cf3..555fef855 100644
--- a/src/types.ts
+++ b/src/types.ts
@@ -400,12 +400,14 @@ export interface JSONRPCPayload {
}
/*
* pollingIntervalMs: How often to poll the Ethereum node for new events.
* numConfirmations: How many confirmed blocks deep you wish to listen for events at.
*/
export interface OrderStateWatcherConfig {
- pollingIntervalMs?: number;
- numConfirmations: number;
+ eventPollingIntervalMs?: number;
+ blockPollingIntervalMs?: number;
+ numConfirmations?: number;
}
/*
@@ -400,12 +400,14 @@ export interface JSONRPCPayload {
}
/*
- * pollingIntervalMs: How often to poll the Ethereum node for new events.
+ * eventPollingIntervalMs: How often to poll the Ethereum node for new events
+ * blockPollingIntervalMs: How often to poll the Ethereum node for new blocks
* numConfirmations: How many confirmed blocks deep you wish to listen for events at.
*/